@@ -1,11 +1,10 @@
 package Bot::Backbone::Dispatcher;
-{
-  $Bot::Backbone::Dispatcher::VERSION = '0.141180';
-}
+$Bot::Backbone::Dispatcher::VERSION = '0.142220';
 use v5.10;
 use Moose;
 
 use Bot::Backbone::Types qw( PredicateList );
+use Bot::Backbone::Dispatcher::PredicateIterator;
 
 # ABSTRACT: Simple dispatching tool
 
@@ -66,19 +65,29 @@ sub add_predicate_or_return {
     }
 }
 
+
+sub predicate_iterator {
+    my $self = shift;
+    return Bot::Backbone::Dispatcher::PredicateIterator->new(
+        dispatcher => $self,
+    );
+}
+
 __PACKAGE__->meta->make_immutable;
 
 __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Bot::Backbone::Dispatcher - Simple dispatching tool
 
 =head1 VERSION
 
-version 0.141180
+version 0.142220
 
 =head1 SYNOPSIS
 
@@ -120,6 +129,15 @@ Chances are that you probably don't need this method. However, if you are creati
 
 This will do the right thing to either add a root level predicate to the dispatcher or return the predicate for chaining within another predicate. You probably want to read the code in L<Bot::Backbone::DispatchSugar> for examples.
 
+=head2 predicate_iterator
+
+  my $iterator = $dispatcher->predicate_iterator;
+  while (my $predicate = $iterator->next) {
+      # do something...
+  }
+
+Returns a L<Bot::Backbone::Dispatcher::PredicateIterator> for this dispatcher.
+
 =head1 AUTHOR
 
 Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
