@@ -1,9 +1,7 @@
 package Bot::Backbone::Service::ConsoleChat;
-{
-  $Bot::Backbone::Service::ConsoleChat::VERSION = '0.141180';
-}
+$Bot::Backbone::Service::ConsoleChat::VERSION = '0.142220';
 use v5.10;
-use Moose;
+use Bot::Backbone::Service;
 
 with qw(
     Bot::Backbone::Service::Role::Service
@@ -150,13 +148,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Bot::Backbone::Service::ConsoleChat - Chat with an interactive command line
 
 =head1 VERSION
 
-version 0.141180
+version 0.142220
 
 =head1 SYNOPSIS
 
